# -*- encoding:utf-8 -*-
import json
import re


# 定义一个辅助函数用于获取嵌套字典中的值
def get_nested(dic, keys, default=None):
    for key in keys:
        if isinstance(dic, dict):
            dic = dic.get(key, default)
        else:
            return default
    return dic

def inner_post_processing(base_info):
    # print(json.dumps(base_info,ensure_ascii=False,indent=4))
    """
    处理 '基础信息' 部分，提取所需字段。

    参数:
        base_info (dict): 包含 '基础信息' 的字典。

    返回:
        dict: 提取的信息字典 extracted_info。
    """
    # 初始化提取的信息字典
    extracted_info = {}

    # 定义一个辅助函数用于递归查找包含特定子字符串的键
    def find_keys_containing(dic, substring):
        found_values = []
        if isinstance(dic, dict):
            for key, value in dic.items():
                if substring in key:
                    found_values.append(value)
                if isinstance(value, dict):
                    found_values.extend(find_keys_containing(value, substring))
                elif isinstance(value, list):
                    for item in value:
                        if isinstance(item, dict):
                            found_values.extend(find_keys_containing(item, substring))
        return found_values

    # 定义一个辅助函数用于根据候选键列表提取值（部分匹配）
    def extract_field(contact_info, candidate_keys):
        for candidate in candidate_keys:
            for key, value in contact_info.items():
                if candidate in key and value not in ["未知", ""]:
                    return value
        return ""

    # 定义一个辅助函数用于提取 '投标保证金'
    def extract_bid_bond(guarantee_info):
        # 定义投标保证金的候选键
        bid_bond_candidates = ["投标保证金", "磋商保证金"]

        # 第一步：查找包含 "投标保证金" 或 "磋商保证金" 的键
        for candidate in bid_bond_candidates:
            for key, value in guarantee_info.items():
                if candidate in key:
                    if isinstance(value, dict):
                        # 在嵌套字典中查找包含 "金额" 的键
                        for sub_key, sub_value in value.items():
                            if "金额" in sub_key and sub_value not in ["未知", ""]:
                                return sub_value
                    elif isinstance(value, str):
                        if "金额" in key and value not in ["未知", ""]:
                            return value
                    else:
                        # 如果 value 既不是 dict 也不是 str，忽略
                        continue

        # 第二步：如果没有找到包含 "金额" 的键，尝试在所有键值中查找符合模式的值
        amount_pattern = re.compile(r'(?:\d{1,3}(?:[,，]\d{3})*(?:\.\d+)?|\d+(?:\.\d+)?|[\u4e00-\u9fff]+(?:\.\d+)?)\s*(?:元|万元)')
        for key, value in guarantee_info.items():
            if isinstance(value, str):
                match = amount_pattern.search(value)
                if match:
                    return match.group()
            elif isinstance(value, dict):
                # 递归查找嵌套字典中的金额
                found_amount = extract_bid_bond(value)
                if found_amount:
                    return found_amount
        # 如果都没有找到，则返回空字符串
        return ""

    # 定义所需字段的映射关系，暂时不包含'联系人'和'联系电话'以及'招标项目地点'
    mapping = {
        "代理机构名称": [["招标人/代理信息", "招标代理机构"]],
        "招标项目名称": [["项目信息", "项目名称"], ["项目信息", "工程名称"]],
        "招标项目编号": [["项目信息", "项目编号"], ["项目信息", "招标编号"]],
        "开标时间": [["关键时间/内容", "开标时间"]],
        "报名截止日期": [["关键时间/内容", "投标文件递交截止日期"]],
        "招标项目预算": [["项目信息", "招标控制价"]],
        "招标单位名称": [["招标人/代理信息", "招标人"]],
        "招标公告地址": [["关键时间/内容", "信息公示媒介"], ["关键时间/内容", "评标结果公示媒介"]],
    }

    # 提取并映射字段
    for new_key, paths in mapping.items():
        value = None
        for path in paths:
            value = get_nested(base_info, path)
            if value:
                break
        extracted_info[new_key] = value if value else ""

    # 特殊处理 '招标项目地点'
    # 在 '项目信息' 下查找包含 "地点" 的键
    project_info = base_info.get("项目信息", {})
    location_candidates = find_keys_containing(project_info, "地点")
    if location_candidates:
        # 选择第一个找到的地点
        extracted_info["招标项目地点"] = location_candidates[0]
    else:
        extracted_info["招标项目地点"] = ""

    # 特殊处理 '联系人' 和 '联系电话'
    # 提取 '项目联系方式'
    project_contact = get_nested(base_info, ["招标人/代理信息", "项目联系方式"], {})
    if not isinstance(project_contact, dict):
        project_contact = {}

    # 提取 '招标人联系方式'
    bidder_contact = get_nested(base_info, ["招标人/代理信息", "招标人联系方式"], {})
    if not isinstance(bidder_contact, dict):
        bidder_contact = {}

    # 定义候选键列表，按优先级排序
    name_candidates = ["联系人","名称", "招标"]
    phone_candidates = ["电话", "手机", "联系方式"]

    # 提取 '联系人'
    contact_names = [project_contact, bidder_contact]
    contact_name = ""
    for contact in contact_names:
        extracted_name = extract_field(contact, name_candidates)
        if extracted_name:
            contact_name = extracted_name
            break
    extracted_info["联系人"] = contact_name

    # 提取 '联系电话'
    contact_phones = [project_contact, bidder_contact]
    contact_phone = ""
    for contact in contact_phones:
        extracted_phone = extract_field(contact, phone_candidates)
        if extracted_phone:
            contact_phone = extracted_phone
            break
    extracted_info["联系电话"] = contact_phone

    # 特殊处理 '投标保证金'
    # 提取 '保证金相关'
    guarantee_info = get_nested(base_info, ["保证金相关"], {})
    if not isinstance(guarantee_info, dict):
        guarantee_info = {}
    extracted_info["投标保证金"] = extract_bid_bond(guarantee_info)

    return extracted_info

def outer_post_processing(combined_data, includes):
    """
    外层处理函数，调用内层 post_processing 处理 '基础信息'，并构建 processed_data。
    额外提取 '采购要求' 下的 '技术要求' 内容。

    参数:
        combined_data (dict): 原始合并数据。
        includes (list): 需要包含的键列表。

    返回:
        tuple: (processed_data, extracted_info, procurement_reqs)
    """
    # 初始化结果字典，预设'其他'分类为空字典
    processed_data = {"其他": {}}

    # 初始化提取的信息字典
    extracted_info = {}

    # 初始化采购要求的技术要求
    procurement_reqs = ""

    # 检查 '基础信息' 是否在 includes 中
    if "基础信息" in includes:
        base_info = combined_data.get("基础信息", {})
        # 调用内层 post_processing 处理 '基础信息'
        extracted_info = inner_post_processing(base_info)
        # 将 '基础信息' 保留在处理后的数据中
        processed_data["基础信息"] = base_info

        # 提取 '采购要求' 下的 '技术要求'
        procurement_reqs = get_nested(base_info, ["采购要求", "技术要求"], "")
        if not procurement_reqs:
            # 如果 '技术要求' 不存在或为空，可以根据需要设置默认值
            procurement_reqs = "未提供"  # 或者其他适当的默认值

    # 遍历原始字典的每一个键值对
    for key, value in combined_data.items():
        if key in includes:
            if key == "基础信息":
                # 已经处理 '基础信息'，无需再次添加
                continue
            else:
                # 直接保留包含在 includes 列表中的键值对
                processed_data[key] = value
        else:
            # 将不在 includes 列表中的键值对加入到 '其他' 分类中
            processed_data["其他"][key] = value

    # 如果 '其他' 分类没有任何内容，可以选择删除这个键
    if not processed_data["其他"]:
        del processed_data["其他"]

    return processed_data, extracted_info, procurement_reqs

if __name__ == "__main__":
    combined_data={
    "开评定标流程": {
        "开标与评标": {
            "开标": [
                "集中采购机构在第一章“投标邀请书”中约定的日期、时间和地点组织公开开标。开标时采购人和投标人代表（投标人法定代表人或其授权代表）参加,参加开标的代表应签到以证明其出席。",
                "投标人法定代表人或其授权代表应携带有效身份证明参加项目开标会，投标人未参加开标的，视同认可开标结果。截止投标文件递交时间，投标人不足3家的，不进行开标。",
                "开标时，由投标人或其推选的代表检查投标文件的密封情况，经确认无误后由集中采购机构工作人员当众拆封，宣布投标人名称、投标价格和招标文件规定的需要宣布的其他内容。",
                "集中采购机构负责对开标过程进行记录，由参加开标的各投标人代表和相关工作人员对开标记录进行签字确认。",
                "投标人代表对开标过程和开标记录有疑义，以及认为采购人、集中采购机构相关工作人员有需要回避的情形的，应当场提出询问或者回避申请。采购人、集中采购机构将及时处理投标人代表提出的询问或者回避申请。"
            ],
            "资格审查": [
                "公开招标采购项目开标结束后，采购人与集中采购机构依据法律、法规及招标文件的规定，对投标人的资格进行审查，以确定投标人资格是否合格。合格投标人不足3家的，不进行评标。",
                "资格审查详见第四章“资格审查方法及标准”。"
            ],
            "评标方法": [
                "最低评标价法。最低评标价法是指投标文件满足招标文件全部实质性要求，且投标报价最低的投标人为中标候选人的评标方法。",
                "综合评分法。综合评分法是指投标文件满足招标文件全部实质性要求，且按照评审因素的量化指标评审得分最高的投标人为中标候选人的评标方法。",
                "评标方法详见第五章“评标方法、程序及标准”。"
            ],
            "评标委员会的组成": [
                "评标委员会由采购人代表和评审专家组成，成员人数应当为5人及以上单数，其中评审专家不得少于成员总数的三分之二；采购预算金额在1000万元及以上、技术复杂或社会影响较大的项目，评标委员会成员人数应当为7人及以上单数。",
                "评标委员会成员依法从政府采购专家库中随机抽取。对技术复杂、专业性强的采购项目，通过随机方式难以确定合适评审专家的，经主管预算单位同意，采购人可以自行选定相应专业领域的评审专家。"
            ],
            "评标程序": {
                "评标委员会负责具体评标事务，并独立履行下列职责：": [
                    "审查、评价投标文件是否符合招标文件的商务、技术等实质性要求；",
                    "要求投标人对投标文件有关事项作出澄清或者说明；",
                    "对投标文件进行综合比较和评价；",
                    "确定中标候选人名单或中标人；",
                    "向采购人、集中采购机构或者有关部门报告评标中发现的违法行为。"
                ],
                "评标程序详见第五章“评标方法、程序及标准”。评标程序详见第五章“评标方法、程序及标准”。": []
            }
        },
        "中标与合同": {
            "确定中标人": {
                "采购人收到评标报告5个工作日内，按评标报告推荐的中标候选人顺序确定中标人。": [],
                "中标候选人并列的：": [
                    "采用最低评标价法的，评标结果按投标报价由低到高顺序排列。投标报价相同的并列，由采购人确定或者采购人委托评标委员会以投票方式确定中标人。",
                    "采用综合评分法的，评标结果按评审后得分由高到低顺序排列。得分相同的，按投标报价由低到高顺序排列。得分且投标报价相同的并列，由采购人确定或者采购人委托评标委员会以投票方式确定中标人。"
                ],
                "中标人的数量有其他规定的，按招标文件相关规定执行。": [],
                "中标人确定后，集中采购机构在政府采购监管部门指定的媒体上发布中标公告，同时向中标人和采购人发出《中标通知书》。《中标通知书》是政府采购合同的组成部分,对中标人和采购人具有同等法律效力。": [],
                "中标通知书发出后，采购人不得违法改变中标结果，中标人无正当理由不得放弃中标。": [],
                "中标人拒绝与采购人签订合同的，采购人可以按照评标报告推荐的中标候选人名单排序，确定下一候选人为中标人，也可以重新开展政府采购活动。": []
            },
            "合同授予": {
                "合同授予": "除本章“确定中标人”规定及其他法律规定的情形外，采购人把合同授予被确定为实质上响应招标文件要求且排名第一的中标人。"
            },
            "合同签订": [
                "采购人应当自中标通知书发出之日起30日内，按照招标文件规定和中标人投标文件的承诺，与中标人签订书面合同。所签订的合同不得对招标文件确定的事项和中标人投标文件作实质性修改。",
                "采购人不得向中标人提出任何不合理的要求作为签订合同的条件。",
                "政府采购合同应当包括采购人与中标人的名称和住所、标的、数量、质量、价款或者报酬、履行期限及地点和方式、验收要求、违约责任、解决争议的方法等内容。",
                "采购人与中标人应当根据合同的约定依法履行合同义务。政府采购合同的履行、违约责任和解决争议的方法等适用《中华人民共和国合同法》。",
                "采购人应当自政府采购合同签订之日起2个工作日内，将政府采购合同在省级以上人民政府财政部门指定的媒体上公告，但政府采购合同中涉及国家秘密、商业秘密的内容除外。",
                "采购人应当加强对中标人的履约管理，并按照采购合同约定，及时向中标人支付采购资金。对于中标人违反采购合同约定的行为，采购人应当及时处理，依法追究其违约责任。采购人应当加强对中标人的履约管理，并按照采购合同约定，及时向中标人支付采购资金。对于中标人违反采购合同约定的行为，采购人应当及时处理，依法追究其违约责任。"
            ]
        }
    },
    "投标文件要求": {
        "投标文件": {
            "投标的语言": {
                "投标的语言": "投标人提交的投标文件以及投标人与集中采购机构或采购人就有关投标的所有来往函电均应使用中文。投标人提交的相关证明文件、资料或文献可以用另一种语言，但相应内容应附有中文翻译本，在解释投标文件的相关内容时以中文翻译本为准。"
            },
            "投标文件的构成": {
                "投标文件的构成": "投标人编制的投标文件应包括但不限于下列内容：第一部分资格证明文件（详见第七章“投标文件格式”中资格证明文件组成），如采购人已组织过项目资格预审的，投标人无需再提交资格证明文件）第二部分商务文件（详见第七章“投标文件格式”中商务文件组成）第三部分技术、服务文件（详见第七章“投标文件格式”中技术、服务文件组成）"
            },
            "投标文件编制": [
                "招标文件有分包要求，投标人对招标文件中多个包进行投标的，其投标文件的编制应按每包要求分别装订和封装，并注明对应包号。",
                "投标人应当对投标文件进行装订成册，采用胶装，采用活页装订的投标文件将作为不合格投标文件处理。",
                "投标人应按照招标文件第七章“投标文件格式”提供的《投标书》、《开标一览表》、《投标报价明细表》、《法定代表人授权书》等格式、要求、规定来编制投标文件。",
                "投标人应对投标文件中所提供资料的真实性负责，若有虚假，将依法承担相应责任。投标人应自觉接受集中采购机构对其中任何资料进一步核实的要求。",
                "因投标人投标文件填报的内容不详，或没有提供招标文件中所要求的全部资料及数据等，由此产生的后果及责任由投标人自行承担。",
                "投标文件用纸应统一为A4规格（图纸除外）。",
                "投标人应将投标文件第一部分资格证明文件、第二部分商务文件、第三部分技术、服务文件分册编制装订，分别逐页连续标注页码，建立目录索引。各部分文件及内容详见第七章“投标文件格式”要求。"
            ],
            "投标报价": {
                "投标人所提供的货物（工程或服务）均以人民币计价。": [],
                "投标人应按照“第三章项目技术、服务及商务要求”规定的货物（工程或服务）内容、责任范围以及合同条款进行报价。并按照《开标一览表》和《投标报价明细表》的格式报出分项价格和投标总价。报价上的优惠应体现在各分项报价中，投标总价应为优惠后的最终报价。投标总价中不得包含招标文件要求以外的内容，否则，在评标时不予核减。": [],
                "《投标报价明细表》填写时应响应下列要求：": [
                    "应包括所有根据合同或其他原因由投标人支付的款项、费用；",
                    "应包含货物运至最终目的地的运输、保险和伴随货物（工程或服务）的有关费用；",
                    "应详细提供《投标报价明细表》和《投标货物、服务清单》等内容，否则按照无效投标处理。"
                ],
                "每一种规格的货物（工程或服务）只允许有一个报价，否则按照无效投标处理。": [],
                "投标人的投标总报价在合同执行过程中是固定不变的，不得以任何理由予以变更。故投标人的投标总报价应包含本招标内容全部工作所需的一切费用，即投标总报价为“交钥匙”价。对在合同实施过程中可能发生的其它费用（如：增加耗材、材料涨价、人工、运输成本增加等因素），采购人不予支付。": [],
                "对于招标文件未列明，而投标人认为必需的费用也需列入其投标总价。在合同实施时，采购人将不予支付投标人没有列入的项目费用，并认为此项目的费用已包括在其投标总价中。": [],
                "投标人应对项目招标范围内的全部内容进行报价，不得缺、漏项或只投其中的部分内容的，否则按照无效投标处理。": []
            },
            "备选方案": {
                "备选方案": "只允许投标人提供一个投标方案（招标文件中要求提供备选方案的除外），否则按照无效投标处理。"
            },
            "中标后分包": {
                "中标后分包": "招标文件规定项目非主体、非关键性工作中标后可以分包的，投标人拟在中标后将项目的非主体、非关键性工作分包，应当在投标文件中载明具备相应资质条件的分包承担主体，分包承担主体不得再次分包。"
            },
            "联合体投标": [
                "两个及以上供应商可以组成一个联合体，以一个投标人的身份共同参与投标。",
                "采取联合体形式投标的，联合体各方均应当符合政府采购法第二十二条第一款规定的条件。联合体的主体应完全满足项目投标人资格要求。",
                "联合体各方之间应签订联合投标协议，明确约定联合体主体及各方承担的工作和相应的责任，其投标文件中应提供联合投标协议。",
                "以联合体形式参加政府采购活动的，联合体各方不得再单独参加或者与其他供应商另外组成联合体参加同一合同项下的政府采购活动。",
                "采取联合体形式投标的，其投标文件应由联合体所有成员或其各自正式书面授权的代表签署（盖章），以便对所有成员作为整体及作为个体均具有法律约束力。",
                "采取联合体形式投标的，项目评审时只对联合体主体进行评议。",
                "联合体中标的，联合体各方应当共同与采购人签订采购合同，就采购合同约定的事项对采购人承担连带责任，联合体主体单位负主要责任。",
                "联合体中有同类资质的供应商按照联合体分工承担相同工作的，应当按照资质等级较低的供应商确定资质等级。",
                "招标文件第一章“投标人资格要求”中未载明是否接受联合体投标的，视同接受。",
                "以联合体形式参与投标的，其价格扣除相关规定详见第五章“评标方法、程序及标准”。"
            ],
            "资格证明文件": [
                "投标人应按本节及第四章“资格审查方法及标准”的要求，提供足以证明其符合项目“投标人资格要求”且中标后有能力履行合同的文件，并作为其投标文件的组成部分。",
                "资格证明文件应真实、合法，并就此承担相应法律责任。",
                "资格证明文件正本应为清晰彩色影印件且加盖单位公章，否则按照无效投标处理。副本可为正本的复印件,但应在副本封面加盖单位公章。",
                "资格证明文件内容详见第四章“资格审查方法及标准”中资格审查内容。",
                "如采购人组织项目资格预审的，集中采购机构将拒绝未通过资格预审投标人的投标。"
            ],
            "投标保证金": "本项目不收取投标保证金，详见本章“投标须知前附表”中的说明。",
            "投标有效期": [
                "投标有效期详见本章“投标须知前附表”中规定。投标文件中承诺的投标有效期应当不少于招标文件中载明的投标有效期。投标有效期不足的，按照无效投标处理。",
                "特殊情况下，在原投标有效期截止之前，集中采购机构或采购人可要求投标人延长投标有效期。这种要求与答复均应以书面形式提交。投标人可拒绝集中采购机构或采购人的这种要求，但其投标在原投标有效期期满后将不再有效。同意延长投标有效期的投标人不会被要求和允许修正其投标内容。"
            ],
            "投标文件的数量和签署": [
                "投标人应按本章“投标须知前附表”中规定的份数要求编制投标文件，投标文件的副本可为正本的复印件,但应在副本封面加盖单位公章。每套投标文件应清楚地标明“正本”、“副本”。副本与正本不一致的，以正本为准。",
                "投标文件的正本应打印或用不褪色墨水书写，应由法定代表人或经其正式授权的代表签字或盖章。由被授权代表签字的，应以书面形式出具授权证明，其《法定代表人授权书》应附在投标文件中。",
                "投标文件中任何涂改和增删，应由法定代表人或经其正式授权的代表在旁边签字后方为有效。",
                "招标文件中要求加盖公章及签字（签章）之处，投标文件正本中应按要求提供加盖公章及签字（签章）的原件，否则按照无效投标处理。"
            ],
            "投标文件的密封和标记": {
                "投标文件包括第一部分资格证明文件，第二部分商务文件，第三部分技术、服务文件,上述三部分应分别密封在独立封包中，并在封包上标明各部分名称，每个封包内应包括正本1份、副本2份。（如采购人已组织过项目资格预审的，投标人无需再提交资格证明文件）": [
                    "资格证明文件正本1份、副本2份，密封在“资格证明文件”封包内，封包上注明“第一部分资格证明文件”；",
                    "商务文件正本1份、副本2份，密封在“商务文件”封包内，封包上注明“第二部分商务文件”；",
                    "技术、服务文件正本1份、副本2份，密封在“技术、服务文件”封包内，封包上注明“第三部分技术、服务文件”。"
                ],
                "为方便开标时唱标，投标人应将《开标一览表》原件一份装入一个信封，单独密封提交，并在信封上注明“开标一览表”字样。未单独提交或单独提交的上述资料未按照招标文件规定的格式填写完整并签字、盖章的集中采购机构拒绝其投标。": [],
                "“开标一览表”信封和投标文件各部分的封包上还应注明采购项目编号、项目名称、投标内容和有“在（招标文件中规定的开标日期和时间）之前不得启封”的字样，封口处加盖投标人公章。": [],
                "未按要求密封、标记或存在错误，集中采购机构对其误投或提前启封概不负责。": []
            },
            "投标文件递交": [
                "投标人应在不迟于投标邀请书中规定的投标截止日期和时间将投标文件密封递交至集中采购机构规定的投标地点。",
                "集中采购机构拒收逾期送达或者未按招标文件要求密封的投标文件。",
                "集中采购机构收到投标文件后，应当如实记载投标文件的送达时间和密封情况，签收保存，并向投标人出具签收回执。"
            ],
            "投标文件的修改和撤回": [
                "投标人在投标截止时间前，可以对所递交的投标文件进行补充、修改或者撤回，并书面通知集中采购机构。补充、修改的内容应当按照招标文件要求签署、盖章、密封后，作为投标文件的组成部分。",
                "投标有效期内投标人不得撤销其投标文件。",
                "投标人所递交的投标文件无论中标与否不予退还。投标人所递交的投标文件无论中标与否不予退还。"
            ]
        }
    },
    "无效标与废标项": {
        "否决和无效投标情形": [
            "法律、法规和招标文件规定的其他无效投标情形。",
            "只允许投标人提供一个投标方案（招标文件中要求提供备选方案的除外），否则按照无效投标处理。",
            "资格证明文件正本应为清晰彩色影印件且加盖单位公章，否则按照无效投标处理。",
            "本表应按要求由投标人法人授权代表签字，并加盖投标人公章，否则将按照无效投标处理。",
            "应详细提供《投标报价明细表》和《投标货物、服务清单》等内容，否则按照无效投标处理。",
            "所递交的资格证明文件出现不符合下列情形之一或不足以证明其符合下列情形之一的，应视为资格审查不合格，并按照无效投标处理：",
            "评标委员会应当对符合资格的投标人的投标文件进行符合性审查，以确定其是否满足招标文件的实质性要求。符合性审查出现下列情形之一的投标按照无效投标处理：",
            "招标文件中要求加盖公章及签字（签章）之处，投标文件正本中应按要求提供加盖公章及签字（签章）的原件，否则按照无效投标处理。",
            "的报价，有可能影响产品质量或者不能诚信履约的，应当要求其在评标现场合理的时间内提供书面说明，必要时提交相关证明材料；投标人不能证明其报价合理性的，评标委员应当将其作为无效投标处理。",
            "投标人应对项目招标范围内的全部内容进行报价，不得缺、漏项或只投其中的部分内容的，否则按照无效投标处理。",
            "在资格审查与评标工作未同日进行的特殊情形下，集中采购机构工作人员在评标时对投标人的信用信息进行复核，发现评标当日存在不良信用信息的，由评标委员会按照符合性审查不合格作无效投标处理。",
            "修正后的报价按照本节第4条规定经投标人确认后产生约束力，投标人不确认的，按照无效投标处理。",
            "说明：1）投标人在投标文件《商务要求响应、偏离说明表》中未对以下商务要求逐条说明响应或偏离情况的，其投标按照无效投标处理。<br>32.1集中采购机构在招标活动中的公告、补充、更正、结果等采购信息均依法在政府采购",
            "每一种规格的货物（工程或服务）只允许有一个报价，否则按照无效投标处理。",
            "不少于招标文件中载明的投标有效期。投标有效期不足的，按照无效投标处理。",
            "为方便开标时唱标，投标人应另附《开标一览表》原件一份装入一个信封，单独密封提交，并在信封上标明“开标一览表”字样。未按要求单独提交上述资料或未按照招标文件规定格式填写完整并签字、盖章的，将按照无效投标处理。"
        ],
        "废标项": "",
        "不得存在的情形": [
            "中标人和制造商售后服务中，维修使用的备品备件及易损件应为原厂配件，未经采购人同意不得使用非原厂配件，常用的、容易损坏的备品备件及易损件的价格清单须在投标文件中列出。",
            "号）的相关规定，“凡是使用财政性资金进行政府采购招投标，采购人、采购代理机构和招投标交易场所不得收取投标保证金”。",
            "投标人的投标总报价在合同执行过程中是固定不变的，不得以任何理由予以变更。",
            "投标有效期内投标人不得撤销其投标文件。",
            "投标人应按照“第三章项目技术、服务及商务要求”规定的货物（工程或服务）内容、责任范围以及合同条款进行报价。并按照《开标一览表》和《投标报价明细表》的格式报出分项价格和投标总价。报价上的优惠应体现在各分项报价中，投标总价应为优惠后的最终报价。投标总价中不得包含招标文件要求以外的内容，否则，在评标时不",
            "投标人应按照评标委员会要求的澄清内容在规定时间内做出澄清。投标文件报价出现前后不一致的，按照本节第3条规定进行修正，投标人的澄清、说明或者补正不得超出投标文件的范围或者改变投标文件的实质性内容。",
            "投标内容和有“在（招标文件中规定的开标日期和时间）之前不得启封”的字样，封口处加盖投标人公章。",
            "投标人应对项目招标范围内的全部内容进行报价，不得缺、漏项或只投其中的部分内容的，否则按照无效投标处理。",
            "经采购人允许，潜在投标人可进入项目现场进行考察，但潜在投标人不得因此使采购人承担有关责任和蒙受损失。",
            "招标文件规定项目非主体、非关键性工作中标后可以分包的，投标人拟在中标后将项目的非主体、非关键性工作分包，应当在投标文件中载明具备相应资质条件的分包承担主体，分包承担主体不得再次分包。",
            "以联合体形式参加政府采购活动的，联合体各方不得再单独参加或者与其他供应商另外组成联合体参加同一合同项下的政府采购活动。"
        ]
    },
    "资格审查": {
        "资格性审查": [
            "国家对生产和销售相关产品或提供相关服务有专门法律、行政法规规定的，则 必须提供取得国家有关主管部门行政许可的证明材料。",
            "法人或者其他组织的营业执照等证明文件，自然人的身份证明（投标人根据自身情况提供对应的证明材料）：",
            {
                "法人": [
                    "企业法人（包括合伙企业）：提供工商部门注册的有效“企业法人营业执照” 或“营业执照”；",
                    "事业单位法人：提供有效的“事业单位法人证书”。"
                ],
                "其他组织": [
                    "非企业专业服务机构：提供执业许可证等证明文件；",
                    "个体工商户：提供有效的“个体工商户营业执照”。"
                ],
                "自然人": "提供有效的自然人身份证明。（仅限中国公民）"
            },
            "财务状况报告，依法缴纳税收和社会保障资金的相关材料（投标人根据自身情况提供对应的证明材料）：",
            {
                "财务状况报告": [
                    "法人：提供经第三方审计的财务报告（完整的财务报告，包括“四表一注”， 即资产负债表、利润表、现金流量表、所有者权益变动表及其附注），或其基本开户银行出具的资信证明；",
                    "部分其他组织和自然人：没有经第三方审计的财务报告的，可以提供银行出具 的资信证明；",
                    "投标人没有经第三方审计的财务报告和资信证明时，也可以提供财政部门认可 的政府采购专业担保机构出具的投标担保函。"
                ]
            },
            {
                "依法缴纳税收和社会保障资金的证明材料": [
                    "法人 a.税务登记证（国税、地税或多证合一）； b.参加政府采购活动前一段时间内缴纳增值税、营业税和企业所得税的凭据； c.社会保险登记证（或多证合一）； d.参加政府采购活动前一段时间内缴纳社会保险的凭据（专用收据或社会保险 缴纳清单）。",
                    "其他组织和自然人 a.参加政府采购活动前一段时间内缴纳税收的凭据； b.参加政府采购活动前一段时间内缴纳社会保险的凭据(专用收据或社会保险 缴纳清单)。",
                    "依法免税或不需要缴纳社会保险资金的投标人 提供其依法免税或不需要缴纳社会保险资金的相关证明文件。"
                ]
            },
            "具备履行合同所必需的设备和专业技术能力的证明材料：",
            "提供具备足够数量的设施设备的证明材料；",
            "提供具备足够数量的技术人员的证明材料。",
            "参加政府采购活动前 3年内在经营活动中没有重大违法记录的书面声明：",
            "应严格按照附件格式提交“参加政府采购活动前三年内在经营活动中没有重大违法记录的书面声明函”；",
            "政府采购法第二十二条第一款第五项所称重大违法记录，是指供应商因违法经营受到刑事处罚或者责令停产停业、吊销许可证或者执照、较大数额罚款等行 政处罚；",
            "按照财政部《关于规范政府采购行政处罚有关问题的通知》的规定，各级人民政府财政部门依法对参加政府采购活动的供应商作出的禁止参加政府采购活动等行政处罚决定在全国范围内生效。",
            "具备法律、行政法规规定的其他条件的证明材料：",
            "应未被“信用中国”网站(www.creditchina.gov.cn)、“中国政府采购网” (www.ccgp.gov.cn)列入失信被执行人、重大税收违法案件当事人名单、政府采购 严重违法失信行为记录名单”；",
            "招标文件第一章“投标人资格要求”中有特殊要求的，投标人应提供其符合特 殊要求的证明材料或者情况说明；",
            "不符合联合体投标相关规定和要求的；",
            "投标人认为需提供的其它相关资格证明材料；",
            "资格证明文件正本应为清晰彩色影印件且加盖单位公章。"
        ],
        "符合性审查": {
            "1.投标总报价超过项目（分包）预算金额或最高限价的": "投标按照无效投标处理",
            "2.《投标书》、《法定代表人授权书》、《开标一览表》、《投标报价明细表》未提供或不符合招标文件要求的": "投标按照无效投标处理",
            "3.工期（服务期限）、质保期不符合招标文件要求的": "投标按照无效投标处理",
            "4.出现两个或两个以上不同报价的": "投标按照无效投标处理",
            "5.出现两个或两个以上投标方案的（招标文件中要求提供备选方案的除外）": "投标按照无效投标处理",
            "6.投标报价存在缺项、漏项的": "投标按照无效投标处理",
            "7.投标有效期不足的": "投标按照无效投标处理",
            "8.无法定代表人签字（签章）或签字人无法定代表人有效授权的": "投标按照无效投标处理",
            "9.正本未按要求提供加盖公章及签字（签章）原件的": "投标按照无效投标处理",
            "10.符合招标文件第二章“投标人须知”中40条中规定情形，以分公司形式参与投标的，法定代表人授权书未由总公司法定代表人签字（签章）并加盖公章的": "投标按照无效投标处理",
            "11.未按要求提供招标文件第二章“十、其他注意事项”中规定的书面声明的": "投标按照无效投标处理",
            "12.所投货物是通过中国海关报关验放进入中国境内且产自关境外的（招标文件中注明已办理进口产品审核的除外）": "投标按照无效投标处理",
            "13.依据财库[2019]9号文的规定，招标文件采购清单中注明“节能产品”的货物，未提供国家确定的认证机构出具的节能产品认证证书的": "投标按照无效投标处理",
            "14.未提供所投货物（工程或服务）的具体参数值或功能表述，或原文复制招标文件的技术规格相关部分内容作为其投标文件的一部分的": "投标按照无效投标处理",
            "15.不满足招标文件第三章“项目技术、服务和商务要求”中“★”号条款要求的": "投标按照无效投标处理",
            "16.含有采购人不能接受的附加条件的": "投标按照无效投标处理",
            "17.未按要求提供《符合性审查对照表》、《商务要求响应、偏离说明表》、《商务要求“★”号条款响应、偏离说明表》、《商务评议对照表》和《技术、服务要求响应、偏离说明表》、《技术、服务要求“★”号条款响应、偏离说明表》、《技术、服务评议对照表》的": "投标按照无效投标处理",
            "18.法律、法规和招标文件规定的其他无效投标情形": "投标按照无效投标处理"
        }
    },
    "技术评分": {
        "技术参数": {
            "评分": "30分",
            "要求": "投标人在投标文件《技术、服务要求响应、偏离说明表》中对应所投产品进行响应描述或偏离说明，完全满足或优于招标文件要求的得 30分，仅注明“符合”或“满足”或原文复制招标文件参数的不得分，▲号技术参数每负偏离一项扣 2分，其他技术参数每负偏离一项扣 1分，扣完为止。（注：参数以提供招标文件中要求的官方证明材料、截图、检测报告等为准）。"
        },
        "投标样机": {
            "评分": "4分",
            "要求": "提供所投教师办公电脑终端产品样机。样机作为评标委员会评定投标人是否满足招标技术文件参数的另一重要依据。样机是项目实施完成后验收的依据。提供样的机投标人，得 4分，否则不得分。"
        },
        "产品的稳定性和技术先进性": {
            "评分": "5分",
            "要求": "1、为保障用户数据安全，教师办公电脑终端产品制造商需提供三年硬盘维修不返还服务，所投教师办公电脑终端硬盘具有减震保护装置，提供证明材料复印件，加盖制造商公章，得 2分，否则不得分。2、为保障使用过程信息及人身安全，所投教师办公电脑终端产品通过数据接口性能和棱缘试验测试合格证明，提供加盖公章的 CNAS权威机构证明材料，得 2分，否则不得分。3、所投交互式电视电脑一体制造商获得IECQ ESD（静电放电）证书的，得 1分，提供证明材料复印件，提供网上查询截图证明，加盖制造商公章，否则不得分。"
        }
    },
    "商务评分": {
        "商务评分": {
            "文件编制": {
                "评分": "2分",
                "要求": "投标文件编制完整，逐页有连续页码、有详细目录、目录与有关材料装订顺序对应清晰、查阅方便，全面响应招标文件得 2分，有缺项酌情打分。"
            },
            "投标人资质": {
                "评分": "2分",
                "要求": "1、投标人获得 ISO9001质量管理体系认证、ISO 14001环境管理体系认证及OHSAS18001职业健康安全管理体系认证，得 2分，否则不得分。（提供证书复印件，加盖投标人公章）；"
            },
            "制造商综合实力": {
                "评分": "2分",
                "要求": "1、为保障产品出厂质量，所投教教师办公电脑终端、交互式电视电脑一体机制造商均获得中国合格评定国家认可委员会（CNAS）授权实验室认可证书的，得 1分，提供证明材料复印件，提供网上查询截图证明，加盖制造商公章，否则不得分。2、响应国家环保要求，所投教师办公电脑终端、交互式电视电脑一体机制造商荣获工业和信息化部《工业产品绿色设计示范企业》的，得 1分，提供证明材料复印件，提供网上查询截图证明，加盖制造商公章，否则不得分；"
            },
            "业绩": {
                "评分": "7分",
                "要求": "1、投标人提供近 3年内（以合同时间为准），类似的成功案例（规模需与本项目相当），每提供一个案例的得 0.5，满分 1分。需提供中标通知书、合同复印件及中标公告网络截图三项证明材料，并加盖投标人公章，否则不得分。2、提供所投教师办公电脑终端产品制造商，近 3年第三方权威咨询机构（IDC或 CCW）数据证明，全球商用市场销量排名连续前 3名，得 5分，排名 4-6名的得 1分，其他不得分。提供以上全部资料复印件并加盖制造商公章，否则不得分。3、所投交互式电视电脑一体机制造商近 2年（以合同时间为准），参加政府采购活动，类似成功案例，每提供一个案例的得 0.5分，满分 1分。需提供中标通知书、合同复印件及中标公告网络截图三项证明材料，并加盖投标人公章，否则不得分。"
            },
            "产品授权及售后服务承诺函": {
                "评分": "2分",
                "要求": "提供满足招标文件质保要求的所投产品制造商售后服务承诺函齐全的，得 2分。否则不得分。"
            }
        },
        "投标报价评审": {
            "项目报价": {
                "评分": "40分",
                "要求": "评标委员会只对符合性审查合格的投标文件进行价格评议，报价分采用低价优先法计算，即满足招标文件要求且投标价格（落实政府采购政策进行价格调整的，以调整后的价格计算）最低的投标报价为评标基准价，其价格分为满分。其他投标人的价格分按照下列公式计算：报价得分=(评标基准价／投标报价)×40 分"
            }
        }
    },
    "基础信息": {
        "招标人/代理信息": {
            "招标人": "广水市教育技术装备站",
            "招标人联系方式": {
                "名称": "广水市教育技术装备站",
                "联系电话": "0722-6233373",
                "地址": "广水市应山办事处西正街29号"
            },
            "招标代理机构": "广水市政府采购中心",
            "招标代理机构联系方式": {
                "名称": "广水市政府采购中心",
                "联系电话": "0722-6265331",
                "地址": "广水市永阳大道40号"
            },
            "项目联系方式": {
                "名称": "周和斌",
                "联系电话": "07226233373"
            }
        },
        "项目信息": {
            "项目名称": "2020年广水市中小学教师办公电脑系统及多媒体“班班通”设备采购安装项目",
            "项目编号": "GSZC-2020-GK-009",
            "项目概况": "2020年广水市中小学教师办公电脑系统及多媒体“班班通”教学设备采购安装项目",
            "项目基本情况": {
                "项目编号": "GSZC-2020-GK-009",
                "项目名称": "2020年广水市中小学教师办公电脑系统及多媒体“班班通”设备采购安装项目",
                "预算金额": "492.39万元整",
                "最高限价": "486万元整",
                "采购需求": [
                    "1.教师办公电脑终端 1197套",
                    "2.教师办公电脑终端云管理软件1197套",
                    "3.教学用交互式电视电脑一体机 30套",
                    "4.壁挂式视频展台 30套",
                    "5.推拉式搪瓷教学板 30套",
                    "6.多媒体安装调试 30套"
                ],
                "项目计划工期": "50个日历天",
                "本项目不接受联合体投标": "本项目不接受联合体投标"
            },
            "招标控制价": "486万元整",
            "投标竞争下浮率": "未知",
            "是否接受联合体投标": "否",
            "分包": "不允许"
        },
        "采购要求": {
            "技术要求": {
                "教师办公电脑终端": {
                    "机型": "1. ★机型：品牌商用型一体台式计算机；",
                    "显示屏": "2. ▲显示屏：≥21.5寸全高清 FHD液晶显示屏(1920x1080)，窄边框设计，亮 度调节物理按键、屏幕开关按钮，带低蓝光护眼功能；",
                    "CPU": "3. ★CPU：≥物理四核心四线程处理器，基础主频：≥3.2GHz，缓存：≥8MB；",
                    "内存": "4. ★内存：≥单根 8G DDR4 2666MHZ内存，≥2个内存插槽；",
                    "显卡": "5.显卡：≥2G DDR5显卡；",
                    "硬盘": "6. ▲硬盘：≥256G M.2 PCIe固态硬盘，支持扩展机械硬盘；",
                    "网卡": "7.网卡：集成 10/100/1000M以太网卡+802.11无线网卡及蓝牙；",
                    "接口": "8. ▲接口：6个USB接口（至少2个前置USB 3.0其中前置1个支持快速充电）， Mic-in×1，Speaker-out×1，HDMI视频接口，串口、6合一读卡器；",
                    "摄像头": "9. ▲摄像头：内置≥720P摄像头；",
                    "音频设备": "10.音频设备：标配麦克风、内置音箱：",
                    "键盘鼠标": "11.键盘鼠标：USB键盘、鼠标，支持键盘开机功能，方便使用；",
                    "机箱": "12. ▲机箱：多功能平放式底座，支持屏幕俯仰、高度调整、左右旋转，方便 维护；",
                    "操作系统": "13.操作系统：预装正版Windows 10简体中文版系统，每台机身均需粘贴正版 COA标贴，微软正版可查；",
                    "保修": "14. ▲保修：三年免费保修，提供厂家工程师上门安装服务，报修第二工作日 上门服务；"
                },
                "教师办公电脑终端云管理软件": {
                    "整体要求": "支持 X86架构，可快速实现教师办公电脑终端的操作系统及应用环境部署管理。整体集中控制、集中管理、快速高效、安全可靠。",
                    "服务端分级管理": "学校等单位可通过本地管理服务器为本单位终端提供桌面服务，保证管理的效率和及时性；市级管理服务器既具备下级服务器的所有功能，并能够查看所有下级学校等单位使用的终端的各种状态信息，具备全局管理的能力。（提供此功能界面截图证明）",
                    "双架构": "为保证各种操作系统场景和浏览器环境条件下均能正常进行管理，云桌面管理平台需是B/S和 C/S双架构，桌面更新模式需具备自动更新和手动更新两种。（提供此功能界面截图证明）",
                    "BT服务端设置": "云桌面管理平台需具备 BT服务端设置和 BT客户端设置功能，避免影响当前业务使用。（提供此功能界面截图证明）",
                    "WEB管理界面": "WEB管理界面可管控教师办公电脑终端状态：在线时长、IP地址、MAC 地址、机器名、网关，并能进行增、改、删等操作。（提供此功能界面截图证明）",
                    "终端信息管理": "可管控教师办公电脑终端信息：主板、CPU、内存、硬盘、显卡等资产配置及变更信息，同时可监控 CPU等温度。（提供此功能界面截图证明）",
                    "快速恢复和还原": "可实现教师办公电脑终端自主快速恢复和还原，需 1分钟内将系统回溯到 健康状态。",
                    "远程控制": "可实现教师办公电脑终端远程开机、重启、关机及发送消息，可自定义编写、保存、下发各种系统命令至教师办公执行终端。（提供此功能界面截图证明）",
                    "虚拟盘格式": "支持.vhd虚拟盘格式，保证系统兼容性(Win7，win10)。（提供此功能界面截图证明）",
                    "差异盘功能": "需具备差异盘的功能，依据客户需求提供不同的虚拟硬盘。",
                    "背景更新和增量更新": "支持背景更新和增量更新，可支持在不影响办公终端操作的情况下进行 更新。",
                    "使用时间设置": "需具备使用时间设置功能，方便教师办公电脑终端的管理。（提供此功能界面截图证明）",
                    "权限管理": "具备权限管理功能，可创建多个账号，自定义管理权限。（提供此功能界面截图证明）",
                    "著作权登记证书": "为保证云桌面产品的产品品质及售后保障，需提供云桌面的软件的著作权登记证书（需提供证书复印件并加盖生产厂商公章）。",
                    "软件售后": "软件售后提供伴随云终端生命周期内的永久性授权使用权限，提供厂商售后服务承诺函。"
                },
                "教学用交互式电视电脑一体机": {
                    "整机设计": "★整机采用一体设计，金属边框，外部无任何可见内部功能模块连接线。显示尺寸≥75英寸；LED液晶屏；屏幕分辨率 3840*2160；亮度：≥300cd/ ㎡。对比度：≥3000:1；屏幕表面采用≥4mm厚全钢化玻璃，具备防眩光效果。",
                    "触控技术与触摸性能": "▲触控技术与触摸性能：免驱、免校正红外触摸技术，即插即用，20点触控。支持 2mm极细笔书写，触控精度高、反应灵敏，书写笔迹定位准确，笔迹呈现清晰完整。",
                    "抗强光干扰功能": "具备抗强光干扰功能：在照度 100K Lux的光照下保证正常触控、书写。",
                    "触摸面材质": "触摸面材质：屏幕表面采用≥4mm，硬度≥7H、可见光透射比≥88%防眩钢化玻璃。",
                    "安卓系统": "一体机安卓系统≥安卓 8.0，安卓系统 CPU处理器:≥4核 64位处理器，存储内存≥16GByte，运行内存 DDR≥2GByte，保证安卓下程序运行速度。",
                    "无线网络模块": "整机内置无线网络模块，PC模块无任何外接或转接天线及网卡可实现 WiFi无线上网连接，支持 5G无线 WiFi，该无线设备通过工信部无线电管理规定和技术标准的认证。",
                    "接口": "▲接口：具备HDMI、USB3.0、VGA、AV、耳机、同轴、RJ45等常规音视频与网络接口；前置双系统通用USB接口数≥3（同一个 USB接口可支持同时在Windows及 Android系统下被读取）其中USB3.0≥1。",
                    "内置摄像头": "▲内置摄像头（不接受外接摄像头），像素≥500万，支持二维码扫码识别功能，帮助用户调用在线资源。内置摄像头支持通过人脸识别解锁交互智能平板。",
                    "扬声器": "整机内置 2个扬声器，左右输出功率≥ 2*15W。",
                    "智能U盘锁功能": "▲支持智能 U盘锁功能，整机可设置触摸及按键自动锁定，保证无关人士无法自由操作，需要使用时只需插入USBkey即可解锁。",
                    "外接电脑设备连接": "外接电脑设备通过标准TypeC线连接至整机 TypeC口；",
                    "护眼功能": "整机具有具备护眼功能：具备智能护眼功能，可实现智能光控，如能通过环境光的智能检测，自动调节屏幕亮度；或智能过滤有害光等。",
                    "一键除雾功能": "▲具有一键除雾功能，针对气候环境潮湿的区域可快速消除屏幕结雾。",
                    "遥控器及配件": "标配遥控器，具备电视遥控功能。配置无线键盘、无线鼠标及电子翻页笔。",
                    "触摸中控菜单": "内置触摸中控菜单，将信号源通道切换、护眼、声音调节等整合到同一菜单下，以实现常用系统快捷菜单和电子白板软件快捷菜单。平时不用时一键隐藏,不影响和占用屏幕的实际尺寸，整机触摸区域无图标按键，不占用屏幕面积。",
                    "模块化电脑": "★采用抽拉内置式模块化电脑，PC模块可插入整机，可实现无单独接线的插拔，无需工具就可快速拆卸电脑模块，与一体机采用 intel标准 80针 OPS接口连接，模块化电脑支持独立使用；IntelCore i5 CPU；8G DDR4内存或以上配置内存；256G固态硬盘；",
                    "模块化电脑操作系统": "▲模块化电脑标配正版Windows10 64位操作系统；具有独立非外扩展的电脑USB接口：至少具备 3个 USB3．0接口，1路 HDMI输出接口。",
                    "售后服务承诺": "提供制造厂家针对本项目产品质保期五年的售后服务承诺函原件并加盖厂家公章。",
                    "检测报告及认证": "以上参数皆需提供一体机具有CNAS机构认可的权威实验室出具的检测报告复印件加盖厂家公章;提供一体机中国国家强制性产品认证（CCC）证书复印件加盖厂家公章；提供制造厂家针对本项目产品质保期五年的售后服务承诺函原件并加盖厂家公章。"
                },
                "壁挂式视频展台": {
                    "1．铝合金外壳，无锐角无利边设计，塑胶包裹，有效防止师生碰伤、划伤。采用折叠开合式托板，展开后托板尺寸≥A4面积，收起时小巧不占空间，高效利用挂墙面积。": "1．铝合金外壳，无锐角无利边设计，塑胶包裹，有效防止师生碰伤、划伤。采用折叠开合式托板，展开后托板尺寸≥A4面积，收起时小巧不占空间，高效利用挂墙面积。",
                    "2．采用USB3．0高速接口，单根USB线实现供电、高清数据传输需求。": "2．采用 USB3．0高速接口，单根USB线实现供电、高清数据传输需求。",
                    "3．▲采用≥800W像素自动对焦摄像头，可拍摄A4画幅。（提供国家权威检测机构出具的检测报告，加盖制造商公章）": "3．▲采用≥800W像素自动对焦摄像头，可拍摄A4画幅。（提供国家权威检测机构出具的检测报告，加盖制造商公章）",
                    "4．支持展台画面实时批注，预设多种笔划粗细及颜色供选择，且支持对展台画面联同批注内容进行同步缩放、移动。": "4．支持展台画面实时批注，预设多种笔划粗细及颜色供选择，且支持对展台画面联同批注内容进行同步缩放、移动。",
                    "5．提供制造厂家针对本项目产品质保期五年的售后服务承诺函原件并加盖厂家公章。": "5．提供制造厂家针对本项目产品质保期五年的售后服务承诺函原件并加盖厂家公章。"
                },
                "推拉式搪瓷教学板": {
                    "1": "定制产品，推拉结构，一次成型设计,一体机置于黑板中间，可根据所配一体机适当调整，确保与一体机的有效配套。",
                    "2": "须符合《书写板安全卫生要求》（GB28231-2011）标准。",
                    "3": "须符合《教学仪器设备产品一般质量要求》（JY 0001-2003）规范。",
                    "4": "每套搪瓷板配蓝色、黑色、红色水解书写笔及墨水各 1套，优质板檫 2个。",
                    "5": "★书写面板：采用比利时进口优质搪瓷板，厚度≥0.4mm，专用书写白色，光泽度≤12光泽度，板面可吸附磁针、磁片，书写面规整光洁，色彩协调对一体机起防撞功用；书写流畅、清晰、易清洁、耐摩擦，面板与衬板需贴实，粘合或压实牢固，衬板材料为高强度泡沫，具有消音，抗潮作用，背板为优质防锈镀锌板，厚度≥0.3mm。",
                    "6": "★边框：横框尺寸≥100×57mm，竖框尺寸≥29mm×100mm，壁厚≥1.2mm，边框经氧化、喷砂涂层处理，无明显眩光；横（立）框采用双层加强结构，与 ABS塑料接角，与滑动板四边铝合金同色；外框厚度根据一体机厚度定制。",
                    "7": "背板：选用优质防锈亚光彩涂钢板，厚度≥0.3mm，背板不影响红外线操控的液晶电视接收信号，操作更快捷，反应更灵敏。",
                    "8": "内芯材料：选用高强度、吸音、防潮、阻燃聚苯乙烯板，厚度≥15mm。",
                    "9": "覆板：采用环保型双组份聚氨酯胶水，自动化流水线覆板作业，背板纵向 间隔 80mm压有 20mm加强筋，胶水 30秒钟即 100%固化定型，确保粘接牢固 板面平整，甲醛释放量≤0.2mg/L。",
                    "11": "包角材料：采用抗老化高强度 ABS工程塑料注塑成型，符合国际 SGS安 全检测认证提供检测报告，无尖角毛刺。",
                    "12": "黑板滑轮：配装侧 U型镶嵌式滑轮，高精度包塑轴承装配减震橡胶圈，保证滑动流畅、经久耐用。数目≥8个，上下均匀安装。推拉顺畅自如，稳定性好，书写时定位精确不晃动、滑动板前后晃动小于 0.5mm。",
                    "13": "限位档：黑板边框内部两侧安装橡胶式隐形限位档，维修一体机时不用拆 卸黑板更加方便。",
                    "14": "安装方式：每块书写板固定八个点，上下各四个，镀锌角铁板隐藏式安装 法。符合GB 21027-2007《学生用品的安全通用要求》。",
                    "15": "书写板通过省级及以上部门检验的书写板检测合格报告并加盖投标人鲜 章。",
                    "16": "提供制造厂家针对本项目产品质保期八年的售后服务承诺函原件并加盖企 业公章。"
                },
                "多媒体安装调试": {
                    "1、常用软件安装，系统部署，备份。": "1、常用软件安装，系统部署，备份。",
                    "2、采用国标一线品牌的强电、弱点线材和辅材，公牛6插位插排。": "2、采用国标一线品牌的强电、弱点线材和辅材，公牛 6插位插排。",
                    "3、现场勘测，布线安装，保证设备能连接互联网，正常使用。": "3、现场勘测，布线安装，保证设备能连接互联网，正常使用。"
                }
            },
            "商务要求": {
                "交货期、交货地点及验收方式": "1、中标人应在采购合同签订后 15个日历日内完成交货； 2、中标人应在采购合同签订后 60个日历日内完成安装调试并可投入使用。（二）交货地点（或为：实施地点） 交货地点：广水市市内各中小学。（三）验收方式 1、到货验收： 到货验收由各项目单位（用户）和中标人共同负责实施。货物到达各项目单位（用户）后，由各项目单位（用户）组织人员和中标人代表在场当面开箱检查，核对货物的品牌、规格型号，查阅货物技术资料、装箱单、合格证等资，检查外观，核实货物数量。到货验收合格条件如下： （1）中标人在合同约定时间内完成交货； （2）货物的品牌、规格型号符合中标人投标的承诺； （3）货物技术资料、装箱单、合格证等资料齐全； （4）货物全新、完好无损； （5）货物数量符合采购人指定各项目单位（用户）配备数量。2、项目初验： 各项目单位货物安装调试完成，运行正常，相关人员技术培训完成后。中标人向项目单位（用户）提供完整的项目实施资料（供货清单，货物和合格证、使用说明书、保修卡，货物安装布线图，培训资料，售后服务联系表。规范装订成册）。由各项目单位（用户）组织初验，初验后按采购人要求填写初验合格证明。3、项目终验： 项目终验由采购人组织并成立验收小组验收。项目终验合格条件如下： （1）设备技术参数与投标文件和采购合同一致，性能指标达到规定的标准； （2）本项目所有项目单位（用户）初验合格（提供项单位初验合格证明）； （3）项目实施资料完整（按采购人要求提供并规范装订成册）。（4）交货、安装完成时间在合同规定时间内完成。",
                "报价要求": "本次报价须为人民币报价，包含：产品价、运输费（含装卸费）、保险费、安装调试费、 税费、培训费等货到采购人指定地点并完成本项目的所有费用。因投标人自身原因造成漏报、 少报皆由其自行承担责任，采购人不再补偿。",
                "质量保证及售后服务": "（一）产品质量保证期 ▲1、投标人应明确承诺：所投教师办公电脑终端免费质保期三年，教学用交互式电视 电脑一体机、视频展台免费质保期五年，推拉式搪瓷教学板免费质保期八年，并提供设备生产 厂家针对此项目的授权书及售后服务承诺函。2、投标产品属于国家规定“三包”范围的，其产品质量保证期不得低于“三包”规定。3、投标人的质量保证期承诺优于国家“三包”规定的，按招标文件要求，投标人承诺 执行。4、投标产品由制造商（指产品生产制造商，或其负责销售、售后服务机构，以下同） 负责标准售后服务的，应当在投标文件中予以明确说明,并附制造商售后服务承诺。（二）售后服务内容 1、投标人和制造商在质量保证期内应当为采购人提供以下技术支持和服务： （1）电话咨询 中标人和制造商应当为采购人提供技术援助电话，解答采购人在使用中遇到的问题，及 时为采购人提出解决问题的建议。▲（2）现场响应 采购人遇到使用及技术问题，电话咨询不能解决的，中标人和制造商应在 2小内到达现 场（远郊区 4小时内到达现场）进行处理，确保产品正常工作；无法在 8小时内解决的，应 在 24小时内提供备用产品，使采购人能够正常使用。（3）技术升级 在质保期内，如果中标人和制造商的产品技术升级，供应商应及时通知采购人，如采购 人有相应要求，中标人和制造商应对采购人购买的产品进行升级服务。（4）在质保期内，中标人每年至少主动为使用单位提供一次售后服务，做好售后服务 记录（使用单位签字盖章），作为退还质保金的依据。2、质保期外服务要求 （1）质量保证期过后，供应商和制造商应同样提供免费电话咨询服务，并应承诺提供 产品上门维护服务。（2）质量保证期过后，采购人需要继续由原供应商和制造商提供售后服务的，该供应 商和制造商应以优惠价格提供售后服务。▲（三）备品备件及易损件 中标人和制造商售后服务中，维修使用的备品备件及易损件应为原厂配件，未经采购人 同意不得使用非原厂配件，常用的、容易损坏的备品备件及易损件的价格清单须在投标文件 中列出。",
                "付款方式": "（一）中标人在合同约定时间内完成交货，经采购人审核确认后，中标人出具全额发票， 采购人在 10个工作日内向市财政局提交申请，支付合同全额的 60%； （二）中标人在合同约定时间内完成所供货物的安装集成并投入正常使用，经采购人组 织验收(终验)合格后，付到合同总额的 35%，余额 5%留作质保金，三个月内付清。",
                "知识产权": "采购人在中华人民共和国境内使用投标人提供的货物及服务时免受第三方提出的侵犯 其专利权或其它知识产权的起诉。如果第三方提出侵权指控，中标人应承担由此而引起的一 切法律责任和费用。",
                "培训": "▲供应商对其提供产品的使用和操作应尽培训义务。供应商应提供对采购人的基本免费 培训，使采购人使用人员能够正常操作。",
                "投标人及产品制造商要求": "▲（一）投标人 投标人获得 ISO9001质量管理体系认证、ISO 14001环境管理体系认证及 OHSAS18001 职业健康安全管理体系认证。以上证明资料提供复印件，加盖制造商公章。▲（二）产品制造商 提供教教师办公电脑终端、交互式电视电脑一体机制造商具有中国合格评定国家认可委 员会（CNAS）授权的《实验室认可证书》复印件，加盖制造商公章。提供教师办公电脑终端、交互式电视电脑一体机制造商获得《工业产品绿色设计示范企 业》证书的复印件，网上查询截图证明，加盖制造商公章。提供教师办公电脑终端产品制造商，近 3年第三方权威咨询机构（IDC或 CCW）数据 证明文件复印件，加盖制造商公章。为保障使用过程信息及人身安全，所投教师办公电脑终端产品通过数据接口性能和棱缘 试验测试合格证明，提供加盖公章的 CNAS权威机构证明材料， 提供权威机构出具的所投教师办公电脑终端硬盘具有减震保护装置的证明文件复印件。提供教师办公电脑终端通过权威认证机构出具的《抗压测试合格》认证证书复印件，加 盖制造商公章。提供交互式电视电脑一体制造商获得《IECQ ESD（静电放电）》认证证书复印件，网 上查询截图证明，加盖制造商公章。",
                "业绩": "投标人提供近 3年内（以合同时间为准），类似的成功案例（规模需与本项目相当）。需提供中标通知书、合同复印件及中标公告网络截图三项证明材料，并加盖投标人公章。提供所投交互式电视电脑一体机制造商近 3年（以合同时间为准），参加政府采购活动， 类似成功案例。需提供中标通知书、合同复印件及中标公告网络截图三项证明材料，并加盖 投标人公章。",
                "其他": "（一）投标人必须在投标文件中对以上条款和服务承诺明确列出，承诺内容必须达到本 篇及招标文件其他条款的要求。（二）其他未尽事宜由供需双方在采购合同中详细约定。"
            },
            "服务要求": {
                "电话咨询": "中标人和制造商应当为采购人提供技术援助电话，解答采购人在使用中遇到的问题，及时为采购人提出解决问题的建议。",
                "现场响应": "采购人遇到使用及技术问题，电话咨询不能解决的，中标人和制造商应在 2小内到达现场（远郊区 4小时内到达现场）进行处理，确保产品正常工作；无法在 8小时内解决的，应在 24小时内提供备用产品，使采购人能够正常使用。",
                "技术升级": "在质保期内，如果中标人和制造商的产品技术升级，供应商应及时通知采购人，如采购人有相应要求，中标人和制造商应对采购人购买的产品进行升级服务。",
                "定期维护": "在质保期内，中标人每年至少主动为使用单位提供一次售后服务，做好售后服务记录（使用单位签字盖章），作为退还质保金的依据。",
                "质保期外服务": "质量保证期过后，供应商和制造商应同样提供免费电话咨询服务，并应承诺提供产品上门维护服务。质量保证期过后，采购人需要继续由原供应商和制造商提供售后服务的，该供应商和制造商应以优惠价格提供售后服务。",
                "备品备件及易损件": "中标人和制造商售后服务中，维修使用的备品备件及易损件应为原厂配件，未经采购人同意不得使用非原厂配件，常用的、容易损坏的备品备件及易损件的价格清单须在投标文件中列出。"
            },
            "其他要求": ""
        },
        "关键时间/内容": {
            "投标文件递交截止日期": "2020年 8月 20日 9点 00分",
            "投标文件递交地点": "广水市公共资源交易中心五楼开标室(二）（广水市永阳大道 40号）",
            "开标时间": "2020年 8月 20日 9点 00分",
            "开标地点": "广水市公共资源交易中心五楼开标室(二）（广水市永阳大道 40号）",
            "澄清招标文件的截止时间": "未知",
            "投标有效期": "提交投标文件截止之日起 90日历日",
            "信息公示媒介": "中国湖北政府采购网 (http://www.ccgp-hubei.gov.cn/) 和中国广水网"
        },
        "保证金相关": {
            "是否提交履约保证金": "未知",
            "投标保证金": "不提交",
            "退还投标保证金": "/",
            "质量保证金": "未知"
        },
        "其他信息": {
            "投标费用承担": "投标人应承担所有与准备和参加投标有关的费用。不论投标的结果如何，集中采购机构和采购人均无义务和责任承担这些费用。",
            "招标代理服务费": "无",
            "是否退还投标文件": "否",
            "投标预备会": "不召开",
            "偏离": {
                "商务要求响应、偏离说明表": "第七章投标文件格式（参考）中的附件十九",
                "商务要求“★”号条款响应、偏离说明表": "第七章投标文件格式（参考）中的附件二十",
                "技术、服务要求响应、偏离说明表": "第七章投标文件格式（参考）中的附件二十二",
                "技术、服务要求“★”号条款响应、偏离说明表": "第七章投标文件格式（参考）中的附件二十三",
                "偏离项的具体要求": "未知"
            },
            "踏勘现场": "不组织"
        }
    }
}
    includes = ["基础信息", "资格审查", "商务评分", "技术评分", "无效标与废标项", "投标文件要求", "开评定标流程"]
    res1,res2,res3=outer_post_processing(combined_data,includes)
    # print(json.dumps(res2,ensure_ascii=False,indent=4))
    print(json.dumps(res3,ensure_ascii=False,indent=4))

